@@ -24,12 +24,12 @@ static const struct log_info_cat default_categories[] = {
 	[DSGSN] = {
 		.name = "DSGSN",
 		.description = "SGSN Emulator",
-		.enabled = 1, .loglevel = LOGL_NOTICE,
+		.enabled = 1, .loglevel = LOGL_INFO,
 	},
 	[DICMP6] = {
 		.name = "DICMP6",
 		.description = "ICMPv6",
-		.enabled = 1, .loglevel = LOGL_DEBUG,
+		.enabled = 1, .loglevel = LOGL_NOTICE,
 	},
 };
 
